@@ -1,24 +1,23 @@
-from .ordered_collection_builder import OrderedCollectionBuilder
+# SPDX-FileCopyrightText: 2023 Helge
+# SPDX-FileCopyrightText: 2024 helge
+#
+# SPDX-License-Identifier: MIT
+
+from . import OrderedCollection
 
 
-def test_ordered_collection_builder():
-    result = OrderedCollectionBuilder("url").build()
+def test_ordered_collection_builder() -> None:
+    result = OrderedCollection(id="url").build()
 
     assert result == {
         "@context": "https://www.w3.org/ns/activitystreams",
         "id": "url",
-        "totalItems": 0,
         "type": "OrderedCollection",
     }
 
 
-def test_ordered_collection_builder_with_items():
-    result = (
-        OrderedCollectionBuilder("url")
-        .with_count(1)
-        .with_items([{"item": "1"}])
-        .build()
-    )
+def test_ordered_collection_builder_with_items() -> None:
+    result = OrderedCollection(id="url", count=1, items=[{"item": "1"}]).build()
 
     assert result == {
         "@context": "https://www.w3.org/ns/activitystreams",
@@ -29,13 +28,8 @@ def test_ordered_collection_builder_with_items():
     }
 
 
-def test_ordered_collection_builder_with_fist_last():
-    result = (
-        OrderedCollectionBuilder("url")
-        .with_count(1)
-        .with_first_and_last("first", "last")
-        .build()
-    )
+def test_ordered_collection_builder_with_fist_last() -> None:
+    result = OrderedCollection(id="url", count=1, first="first", last="last").build()
 
     assert result == {
         "@context": "https://www.w3.org/ns/activitystreams",
